@@ -3,10 +3,11 @@
 # flake8: noqa
 # pylint: skip-file
 
-__version__ = "0.1.2"
+__version__ = "0.1.6"
 
-from puma.fraction_scan import FractionScan, FractionScanPlot
 from puma.histogram import Histogram, HistogramPlot
+from puma.line_plot_2d import Line2D, Line2DPlot
+from puma.pie import PiePlot
 from puma.plot_base import PlotBase, PlotLineObject, PlotObject
 from puma.roc import Roc, RocPlot
 from puma.var_vs_eff import VarVsEff, VarVsEffPlot
